@@ -12,18 +12,21 @@ style_type <- function(x) {
 #' Call [format()] on the result to render column types.
 #'
 #' @param x A vector for which the type is to be retrieved.
-#' @inheritParams ellipsis::dots_empty
+#' @inheritParams rlang::args_dots_empty
 #' @export
 #' @examples
-#' format(new_pillar_type(iris$Species))
+#' format(new_pillar_type("a"))
+#' format(new_pillar_type(factor("a")))
 new_pillar_type <- function(x, ...) {
   "!!!!DEBUG new_pillar_type(`v(class(x))`)"
   if (!missing(...)) {
     check_dots_empty(action = warn)
   }
 
-  type <- get_pillar_type(x)
+  new_pillar_type_obj(get_pillar_type(x))
+}
 
+new_pillar_type_obj <- function(type) {
   # Must wrap in a list, because type_sum() can return a classed object
   ret <- structure(list(type), class = "pillar_type")
   extent <- get_extent(format_type_sum(type, NULL))
@@ -32,7 +35,7 @@ new_pillar_type <- function(x, ...) {
   ret
 }
 
-get_pillar_type <- function(x, shaft) {
+get_pillar_type <- function(x) {
   type <- type_sum(x)
   if (length(type) == 0L) type <- "?"
   # Can return a classed object to be formatted by format_type_sum()
@@ -41,8 +44,12 @@ get_pillar_type <- function(x, shaft) {
 }
 
 #' @export
-format.pillar_type <- function(x, width = NULL, ...) {
-  format_type_sum(x[[1]], width)
+format.pillar_type <- function(x, width = NULL, ..., is_focus = FALSE) {
+  out <- format_type_sum(x[[1]], width)
+  if (is_focus) {
+    out <- crayon_underline(out)
+  }
+  out
 }
 
 format_full_pillar_type <- function(x) {
@@ -64,7 +71,7 @@ format_full_pillar_type <- function(x) {
 #' @param x A return value from `type_sum()`
 #' @param width The desired total width. If the returned string still is
 #'   wider, it will be trimmed. Can be `NULL`.
-#' @inheritParams ellipsis::dots_used
+#' @inheritParams rlang::args_dots_used
 #'
 #' @export
 #' @examples
@@ -87,11 +94,6 @@ format_type_sum <- function(x, width, ...) {
   UseMethod("format_type_sum")
 }
 
-# https://github.com/r-lib/pkgdown/issues/1540
-type_sum.accel <- function(x) {
-  I("kg m/s^2")
-}
-
 #' @export
 #' @rdname format_type_sum
 format_type_sum.default <- function(x, width, ...) {
