@@ -27,6 +27,14 @@ print.pillar_vctr <- function(x, ..., max = NULL) {
 #' @export
 obj_print_header.pillar_vctr <- function(x, ..., .size) {
   writeLines(paste0("<", vec_ptype_full(x), "[", .size, "]>"))
+  pillar_attr <- attr(x, "pillar")
+  if (!is.null(pillar_attr$fixed_exponent)) {
+    shaft <- pillar_shaft_number_attr(numeric(), pillar_attr)
+    type <- attr(shaft, "type")
+    if (!is.null(type)) {
+      writeLines(paste0("Fixed exponent: ", type[[1]]))
+    }
+  }
   invisible(x)
 }
 
@@ -37,7 +45,7 @@ obj_print_data.pillar_vctr <- function(x, ..., .size) {
   }
 
   # FIXME: base::print.default() can't use color, roll own implementation?
-  out <- stats::setNames(strip_sgr(format(x), warn = FALSE), names(x))
+  out <- stats::setNames(ansi_strip(format(x)), names(x))
   print(out, quote = FALSE, max = vec_size(x))
   invisible(x)
 }
