@@ -1,9 +1,8 @@
 # nocov start - zzz.R
 
 #' @import rlang
-#' @import ellipsis
+#' @import lifecycle
 #' @importFrom glue as_glue
-#' @importFrom lifecycle deprecate_soft
 #' @importFrom vctrs data_frame
 #' @importFrom vctrs new_data_frame
 #' @importFrom vctrs new_list_of
@@ -34,9 +33,16 @@
 #' @importFrom vctrs vec_restore
 #' @importFrom vctrs vec_size
 #' @importFrom vctrs vec_slice
-#' @importFrom crayon black
+#' @importFrom cli symbol ansi_strwrap
 NULL
 
+# https://github.com/r-lib/pkgdown/issues/1540
+if (Sys.getenv("IN_PKGDOWN") != "") {
+  type_sum.accel <- function(x) {
+    I("kg m/s^2")
+  }
+}
+
 # nolint start
 .onLoad <- function(libname, pkgname) {
   # nolint end
